Files
dvc/tests
Ruslan Kuprieiev d77af8196e optimize local status (#3867)
* remote: remove unpacked dir

We've done a lot of optimizations lately, which made unpacked dir trick
obsoleted.

* local: save us a stat call in is_protected

* local: speedup checksum_to_path ~x5.5

* tree: walk: don't use os.path.join

It is ~5.5 times slower than joining by hand.

* dvcignore: optimize matching x10

On a repo with a dvcignore with 1 pattern and a directory with 400K
files, `dvc status` now takes ~8 sec instead of ~30 sec.

To achieve that, we make some assumptions about the paths formats that
we are dealing with, so we could use simpler logic instead of using
very slow `relpath`, `abspath` etc on every entry in a directory.

It is also clear that CleanTree behavior is inconsistent (even tests
expect very different outputs from it), so we will need to look into
this later.
2020-05-25 03:20:11 +03:00
..
2020-05-25 03:20:11 +03:00
2020-05-25 03:20:11 +03:00
2020-05-15 16:48:02 +03:00
2020-05-15 16:48:02 +03:00
2020-05-15 16:48:02 +03:00
2020-05-15 16:48:02 +03:00
2020-05-15 16:48:02 +03:00
2019-04-26 18:07:16 +07:00
2019-04-26 18:07:16 +07:00